@@ -6,7 +6,7 @@ base_dir <- if (interactive()) file.path("tests", "testthat") else "."
 context("ratio functions")
 
 # calculate_ratios_sem
-test_that("calculate_ratios_sem() tests", {
+test_that("test calculate_ratios_sem()", {
 
   # success
   expect_equal(calculate_ratios_sem(ratios = c(1, 2, 3)), 0.57735026919)
@@ -15,25 +15,25 @@ test_that("calculate_ratios_sem() tests", {
   # failure
 
   expect_error(calculate_ratios_sem(),
-               "no input vector for ratios supplied",
+               "no input vector for `ratios` supplied",
                fixed = TRUE)
 
   expect_error(calculate_ratios_sem(ratios = matrix(1, 2, 3)),
-              "ratios need to be provided in a vector",
+              "`ratios` need to be provided as a numeric vector",
               fixed = TRUE)
 
   expect_error(calculate_ratios_sem(ratios = c("A", "B", "C")),
-               "ratios need to be a numeric vector",
+               "`ratios` need to be provided as a numeric vector",
                fixed = TRUE)
 
   expect_error(calculate_ratios_sem(ratios = numeric()),
-               "length of ratios needs to be > 1: 0",
+               "length of `ratios` needs to be > 1",
                fixed = TRUE)
 
 })
 
 # calculate_ratios_gmean
-test_that("calculate_ratios_gmean() tests", {
+test_that("test calculate_ratios_gmean()", {
 
   # success
   list <- c(4, 5, 6)
@@ -41,68 +41,64 @@ test_that("calculate_ratios_gmean() tests", {
   expect_equal(calculate_ratios_gmean(ratios = list), 4.9324241486609)
 
   # failure
-  expect_error(calculate_ratios_gmean(), "input vector for ratios supplied")
+  expect_error(calculate_ratios_gmean(), "input vector for `ratios` supplied")
 
   expect_error(calculate_ratios_gmean(ratios = matrix(1, 2, 3)),
-               "ratios need to be provided in a vector",
+               "`ratios` need to be provided as a numeric vector",
                fixed = TRUE)
 
   expect_error(calculate_ratios_gmean(ratios = c("A", "B", "C")),
-               "ratios need to be a numeric vector",
-               fixed = TRUE)
-
-  expect_error(calculate_ratios_gmean(ratios = numeric()),
-               "length of ratios needs to be > 1: 0",
+               "`ratios` need to be provided as a numeric vector",
                fixed = TRUE)
 
 })
 
 # calculate_ratios_gsd
-test_that("calculate_ratios_gsd() tests", {
+test_that("test calculate_ratios_gsd()", {
 
   # success
   expect_type(calculate_ratios_gsd(ratios = c(1, 2, 3)), "double")
 
   # failure
-  expect_error(calculate_ratios_gsd(), "no input vector for ratios supplied")
+  expect_error(calculate_ratios_gsd(), "no input vector for `ratios` supplied")
 
   expect_error(calculate_ratios_gsd(ratios = matrix(1, 2, 3)),
-               "ratios need to be provided in a vector",
+               "`ratios` need to be provided as a numeric vector",
                fixed = TRUE)
 
   expect_error(calculate_ratios_gsd(ratios = c("A", "B", "C")),
-               "ratios need to be a numeric vector",
+               "`ratios` need to be provided as a numeric vector",
                fixed = TRUE)
 
   expect_error(calculate_ratios_gsd(ratios = numeric()),
-               "length of ratios needs to be > 1: 0",
+               "length of `ratios` needs to be > 1",
                fixed = TRUE)
 })
 
 # calculate_ratios_gse
-test_that("calculate_ratios_gse() tests", {
+test_that("test calculate_ratios_gse()", {
 
   # success
   expect_type(calculate_ratios_gse(ratios = c(4, 5, 6)), "double")
 
   # failure
-  expect_error(calculate_ratios_gse(), "input vector for ratios supplied")
+  expect_error(calculate_ratios_gse(), "input vector for `ratios` supplied")
 
   expect_error(calculate_ratios_gse(ratios = matrix(1, 2, 3)),
-               "ratios need to be provided in a vector",
+               "`ratios` need to be provided as a numeric vector",
                fixed = TRUE)
 
   expect_error(calculate_ratios_gse(ratios = c("A", "B", "C")),
-               "ratios need to be a numeric vector",
+               "`ratios` need to be provided as a numeric vector",
                fixed = TRUE)
 
   expect_error(calculate_ratios_gse(ratios = numeric()),
-               "length of ratios needs to be > 1: 0",
+               "length of `ratios` needs to be > 1",
                fixed = TRUE)
 })
 
 # calculate_ratios_slope
-test_that("calculate_ratios_slope() tests", {
+test_that("test calculate_ratios_slope()", {
 
   # success
   x <- c(0, 1, 2, 3)
@@ -111,44 +107,44 @@ test_that("calculate_ratios_slope() tests", {
   expect_equal(calculate_ratios_slope(x, y), 1)
 
   # failure
-  expect_error(calculate_ratios_slope(), "no input vector for x supplied")
+  expect_error(calculate_ratios_slope(), "no input vector for `x` supplied")
 
-  expect_error(calculate_ratios_slope(y = 1), "no input vector for x supplied")
+  expect_error(calculate_ratios_slope(y = 1), "no input vector for `x` supplied")
 
   expect_error(calculate_ratios_slope(x = matrix(1, 2, 3), y = c(1,2,3)),
-               "x needs to be a vector",
+               "`x` needs to be provided as a numeric vector",
                fixed = TRUE)
 
   expect_error(calculate_ratios_slope(x = c("A"), y = c(1,2,3)),
-               "x needs to be a numeric vector",
+               "`x` needs to be provided as a numeric vector",
                fixed = TRUE)
 
   expect_error(calculate_ratios_slope(x = numeric(), y = c(1,2,3)),
-               "length of x needs to be > 1: 0",
+               "length of `x` needs to be > 1",
                fixed = TRUE)
 
-  expect_error(calculate_ratios_slope(x = 1), "no input vector for y supplied")
+  expect_error(calculate_ratios_slope(x = 1), "no input vector for `y` supplied")
 
   expect_error(calculate_ratios_slope(x = c(1,2,3), y = matrix(1, 2, 3)),
-               "y needs to be a vector",
+               "`y` needs to be provided as a numeric vector",
                fixed = TRUE)
 
   expect_error(calculate_ratios_slope(x = c(1,2,3), y = c("A")),
-               "y needs to be a numeric vector",
+               "`y` needs to be provided as a numeric vector",
                fixed = TRUE)
   #
   expect_error(calculate_ratios_slope(x = c(1,2,3), y = c(1)),
-               "length of y needs to be > 1: 1",
+               "length of `y` needs to be > 1",
                fixed = TRUE)
 
   expect_error(calculate_ratios_slope(x = c(1,2,3), y = c(1,2,3,4)),
-               "length of x and y need to be equal",
+               "`x` and `y` need to be vectors of equal length",
                fixed = TRUE)
 
 })
 
-# calculate_weighted.vector.sum
-test_that("calculate_weighted.vector.sum() tests", {
+# calculate_ratios_weighted_sum
+test_that("test calculate_ratios_weighted_sum()", {
 
   # success
   x <- c(2, 4, 6)
@@ -157,89 +153,115 @@ test_that("calculate_weighted.vector.sum() tests", {
   expect_type(calculate_ratios_weighted_sum(x, y), "double")
 
   # failure
-  expect_error(calculate_ratios_weighted_sum(), "no input vector for x supplied")
+  expect_error(calculate_ratios_weighted_sum(), "no input vector for `x` supplied")
 
   expect_error(calculate_ratios_weighted_sum(x = matrix(1, 2, 3),
                                              y = c(1, 2, 3)),
-               "x needs to be a vector",
+               "`x` needs to be provided as a numeric vector",
                fixed = TRUE)
 
   expect_error(calculate_ratios_weighted_sum(x = c("A"),
                                              y = c(1, 2, 3)),
-               "x needs to be a numeric vector",
+               "`x` needs to be provided as a numeric vector",
                fixed = TRUE)
 
   expect_error(calculate_ratios_weighted_sum(x = numeric(),
                                              y = c(1, 2, 3)),
-               "length of x needs to be > 1: 0",
+               "length of `x` needs to be > 1",
                fixed = TRUE)
 
   expect_error(calculate_ratios_weighted_sum(x = c(1, 2, 3)),
-               "no input vector for y supplied")
+               "no input vector for `y` supplied")
 
   expect_error(calculate_ratios_weighted_sum(x = c(1, 2, 3),
                                             y = matrix(1, 2, 3)),
-               "y needs to be a vector",
+               "`y` needs to be provided as a numeric vector",
                fixed = TRUE)
 
   expect_error(calculate_ratios_weighted_sum(x = c(1, 2, 3),
                                              y = c("A")),
-               "y needs to be a numeric vector",
+               "`y` needs to be provided as a numeric vector",
                fixed = TRUE)
 
   expect_error(calculate_ratios_weighted_sum(x = c(1, 2, 3),
                                              y = numeric()),
-               "length of y needs to be > 1: 0",
+               "length of `y` needs to be > 1",
                fixed = TRUE)
 
   expect_error(calculate_ratios_weighted_sum(x = c(1, 2, 3), y = c(1, 2, 3, 4)),
-               "length of x and y need to be equal",
+               "`x` and `y` need to be vectors of equal length",
                fixed = TRUE)
 
 })
 
-# orbi_calculate_ratios
-test_that("orbi_calculate_ratio() tests", {
+# orbi_calculate_ratio
+test_that("test orbi_calculate_summarized_ratio()", {
 
   a <- 1:10
   b <- 1:10
 
   # success
-  expect_equal(orbi_calculate_ratio(a, b, "mean"), 1)
-  expect_equal(orbi_calculate_ratio(a, b, "sum"), 1)
-  expect_equal(orbi_calculate_ratio(a, b, "slope"), 1)
-  expect_equal(orbi_calculate_ratio(a, b, "geometric_mean"), 1)
-  expect_equal(orbi_calculate_ratio(a, b, "weighted_sum"), 1)
-  expect_equal(orbi_calculate_ratio(a, b, "median"), 1)
+  expect_equal(orbi_calculate_summarized_ratio(a, b, "mean"), 1)
+  expect_equal(orbi_calculate_summarized_ratio(a, b, "sum"), 1)
+  expect_equal(orbi_calculate_summarized_ratio(a, b, "slope"), 1)
+  expect_equal(orbi_calculate_summarized_ratio(a, b, "geometric_mean"), 1)
+  expect_equal(orbi_calculate_summarized_ratio(a, b, "weighted_sum"), 1)
+  expect_equal(orbi_calculate_summarized_ratio(a, b, "median"), 1)
+
+  a <- 1
+  b <- 1
+  expect_equal(orbi_calculate_summarized_ratio(a, b, "direct"), 1)
 
   # failure
-  expect_error(
-    orbi_calculate_ratio(a, b, "median2"),
-    "`ratio_method` has to be `mean`, `sum`, `median`, `geometric_mean`, `slope` or `weighted_sum`",
-    fixed = TRUE
-  )
+  expect_error(orbi_calculate_summarized_ratio(numerator = vector("numeric", 2), denominator = vector("numeric", 1), "direct"),
+               "`numerator` and `denominator` must be vectors of equal length")
 
-  expect_error(orbi_calculate_ratio(),
-               "no input for numerator supplied",
+  expect_error(orbi_calculate_summarized_ratio(),
+               "no input for `numerator` supplied",
                fixed = TRUE)
 
-  expect_error(orbi_calculate_ratio(numerator = a),
-               "no input for denominator supplied",
+  expect_error(orbi_calculate_summarized_ratio(numerator = a),
+               "no input for `denominator` supplied",
                fixed = TRUE)
 
-  expect_error(orbi_calculate_ratio(numerator =  as.character(a),
+  expect_error(orbi_calculate_summarized_ratio(numerator =  as.character(a),
                                      denominator = b),
-               "numerator must be a numeric vector",
+               "`numerator` needs to be provided as a numeric vector",
                fixed = TRUE)
 
-  expect_error(orbi_calculate_ratio(numerator =  a,
+  expect_error(orbi_calculate_summarized_ratio(numerator =  a,
                                      denominator = as.character(b)),
-               "denominator must be a numeric vector",
+               "`denominator` needs to be provided as a numeric vector",
                fixed = TRUE)
 })
 
+# orbi_calculate_ratios
+test_that("test orbi_calculate_ratios()", {
+
+  df <- orbi_read_isox(system.file("extdata", "testfile_dual_inlet.isox", package = "isoorbi"))
+  df_results <-
+    df |>
+    # define base peak
+    orbi_define_basepeak("15N")
+
+  # failure
+  expect_error(orbi_calculate_ratios(),
+               "need a `dataset` data frame",
+               fixed = TRUE)
+
+  df_results2 <- subset(df_results, select = -basepeak_ions)
+
+  expect_error(orbi_calculate_ratios(df_results2),
+               "`dataset` requires defined basepeak (columns `basepeak` and `basepeak_ions`), make sure to run `orbi_define_basepeak()` first",
+               fixed = TRUE)
+
+  # deprecation warning
+  expect_warning(orbi_calculate_ratios(df_results), "obsolete")
+
+})
+
 # orbi_summarize_results
-test_that("orbi_summarize_results() tests", {
+test_that("test orbi_summarize_results()", {
 
   # success
 
